.. |name| replace:: ``voxcell``

Welcome to |name|'s documentation!
===================================

|name| is a library aimed to provide an access to brain atlases.

In addition, it could be used for:

* accessing other volumetric datasets in compatible format
* handling probability distributions that have a spatial component
* manipulating vector fields

Contents
--------

.. toctree::
   :maxdepth: 2

   install
   aibs
   atlas
   extras
   formats
   api
   changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

